# CHANGELOG

## 1.1.2
- added wsl bandaid to BookmarksGetter

## 1.1.1
- fixed convert_to_wsl_path

## 1.1.0
- added func to wsl_path

## 1.0.0
- added wsl_paths

## 0.0.1
- added strict type checking
